Package: forcats
Title: Tools for Working with Categorical Variables (Factors)
Version: 1.0.0
Authors@R: c(
    person("Hadley", "Wickham", , "hadley@rstudio.com", role = c("aut", "cre")),
    person("RStudio", role = c("cph", "fnd"))
  )
Description: Helpers for reordering factor levels (including moving
    specified levels to front, ordering by first appearance, reversing,
    and randomly shuffling), and tools for modifying factor levels
    (including collapsing rare levels into other, 'anonymising', and
    manually 'recoding').
License: MIT + file LICENSE
URL: https://forcats.tidyverse.org/,
        https://github.com/tidyverse/forcats
BugReports: https://github.com/tidyverse/forcats/issues
Depends: R (>= 3.4)
Imports: cli (>= 3.4.0), glue, lifecycle, magrittr, rlang (>= 1.0.0),
        tibble
Suggests: covr, dplyr, ggplot2, knitr, readr, rmarkdown, testthat (>=
        3.0.0), withr
VignetteBuilder: knitr
Config/Needs/website: tidyverse/tidytemplate
Config/testthat/edition: 3
Encoding: UTF-8
LazyData: true
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.2.3
Author: Hadley Wickham [aut, cre],
  RStudio [cph, fnd]
Maintainer: Hadley Wickham <hadley@rstudio.com>
Built: R 4.4.0; ; 2024-04-27 22:14:14 UTC; unix
