# Generated by roxygen2: do not edit by hand

S3method(as_factor,character)
S3method(as_factor,factor)
export("%>%")
export(as_factor)
export(fct_anon)
export(fct_c)
export(fct_collapse)
export(fct_count)
export(fct_drop)
export(fct_expand)
export(fct_explicit_na)
export(fct_infreq)
export(fct_inorder)
export(fct_lump)
export(fct_other)
export(fct_recode)
export(fct_relabel)
export(fct_relevel)
export(fct_reorder)
export(fct_reorder2)
export(fct_rev)
export(fct_shift)
export(fct_shuffle)
export(fct_unify)
export(fct_unique)
export(last2)
export(lvls_expand)
export(lvls_reorder)
export(lvls_revalue)
export(lvls_union)
importFrom(magrittr,"%>%")
importFrom(stats,median)
